@@ -15,8 +15,8 @@ Options:
 Copies <logfile> into <logfile>.nt while deleting any log entries that are older 
 than the limit specified by --keep-for.
 """
-__version__ = '0.1'
-__released__ = '2023-04-08'
+__version__ = '0.2'
+__released__ = '2023-04-10'
 
 
 # IMPORTS {{{1
@@ -60,7 +60,10 @@ def main():
     # Command line {{{2
     cmdline = docopt(__doc__)
     logfile = cmdline['<logfile>']
-    keep_for = Quantity(cmdline['--keep-for'], 'd', scale='s')
+    try:
+        keep_for = Quantity(cmdline['--keep-for'], 'd', scale='s')
+    except QuantiPhyError as e:
+        fatal(e, culprit=f'--keep-for={cmdline["--keep-for"]}')
     max_entries = to_int(cmdline['--max-entries'])
     min_entries = to_int(cmdline['--min-entries'])
     delete_given_log = cmdline['--delete']
